/*
 * Created on Jul 17, 2003
 *
 * To change the template for this generated file go to
 * Window>Preferences>Java>Code Generation>Code and Comments
 */
package gov.grants.xmlToDB.dao;

import java.util.*;
import java.sql.*;
import gov.grants.xmlToDB.valueobject.*;

 /**
  * Sf424Cover Data Access Object (DAO).
  * This class contains all database handling that is needed to
  * permanently store and retrieve Sf424Cover object instances.
  */



public class Sf424CoverDao {


    /**
     * load-method. This will load valueObject contents from database using
     * Primary-Key as identifier. Upper layer should use this so that valueObject
     * instance is created and only primary-key should be specified. Then call
     * this method to complete other persistent information. This method will
     * overwrite all other fields except primary-key and possible runtime variables.
     *
     * @param conn         This method requires working database connection.
     * @param valueObject  This parameter contains the class instance to be loaded.
     *                     Primary-key field must be set for this to work properly.
     */
    public static void load(Connection conn, Sf424Cover valueObject) throws SQLException {

          if (valueObject.getGrants_govTrackingNumber() == null) {
               //System.out.println("Can not select without Primary-Key!");
               throw new SQLException("Can not select without Primary-Key!");
          }
          String sql = "SELECT * FROM Sf424Cover WHERE Grants_govTrackingNumber = ?";
          PreparedStatement stmt = null;

          try {
               stmt = conn.prepareStatement(sql);

               stmt.setString(1, valueObject.getGrants_govTrackingNumber());
               singleQuery(conn, stmt, valueObject);

          } finally {
              if (stmt != null)
                  stmt.close();
          }
    }


    /**
     * LoadAll-method. This will read all contents from database table and
     * build an Vector containing valueObjects. Please note, that this method
     * will consume huge amounts of resources if table has lot's of rows.
     * This should only be used when target tables have only small amounts
     * of data.
     *
     * @param conn         This method requires working database connection.
     */
    public static List loadAll(Connection conn) throws SQLException {

          List searchResults;

          String sql = "SELECT * FROM Sf424Cover ";
          sql = sql + "ORDER BY Grants_govTrackingNumber ";

          searchResults = listQuery(conn, conn.prepareStatement(sql));


          return searchResults;
    }



    /**
     * create-method. This will create new row in database according to supplied
     * valueObject contents. Make sure that values for all NOT NULL columns are
     * correctly specified. Also, if this table does not use automatic surrogate-keys
     * the primary-key must be specified. After INSERT command this method will
     * read the generated primary-key back to valueObject if automatic surrogate-keys
     * were used.
     *
     * @param conn         This method requires working database connection.
     * @param valueObject  This parameter contains the class instance to be created.
     *                     If automatic surrogate-keys are not used the Primary-key
     *                     field must be set for this to work properly.
     */
    public static void create(Connection conn, Sf424Cover valueObject) throws SQLException {

          String sql = "INSERT INTO Sf424Cover ( Grants_govTrackingNumber, AuthorizedRepresentativeSignature, SignedDate, AgencySchemaVersion" +
          ", FromVersionIdentifier, SubmissionTypeCode, SubmittedDate" +
          ", ApplicationTypeCode, AgencyName, AgencyReceivedDate" +
          ", StateReceivedDate, StateID, FederalID" +
          ", CFDANumber, ActivityTitle, Assurance" +
          ", StateReviewCode, StateReviewDate, RevisionCode1, RevisionCode2, RevisionOtherExplanation" +
          ", ApplicantID, ApplicantTypeCode, ApplicantTypeCodeOtherExplanation" +
          ", OrganizationName, DUNSID, DepartmentName" +
          ", DivisionName, EmployerID, Street" +
          ", City, County, StateCode" +
          ", ZipCode, Country, DelinquentFederalDebtIndicator, DelinquentFederalDebtExplanation, OrganizationCongressionalDistrict" +
          ", ProjectTitle, Location, ProposedStartDate" +
          ", ProposedEndDate, ProjectCongressionalDistrict, FederalEstimatedAmount" +
          ", ApplicantEstimatedAmount, StateEstimatedAmount, LocalEstimatedAmount" +
          ", OtherEstimatedAmount, ProgramIncomeEstimatedAmount, TotalEstimatedAmount" +
          ", ApplicantNamePrefix, ApplicantGivenName1, ApplicantGivenName2, ApplicantFamilyName, ApplicantNameSuffix" +
          ", ApplicantTelephoneNumber, ApplicantFaxNumber, ApplicantEmail" +
          ", AORNamePrefix, AORGivenName1, AORGivenName2" +
          ", AORFamilyName, AORNameSuffix, AORTelephoneNumber" +
          ", AgencyTrackingNumber, RepresentativeTitle) " +
          "  VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ? )";
          PreparedStatement stmt = null;

          try {
               stmt = conn.prepareStatement(sql);

               stmt.setString(1, valueObject.getGrants_govTrackingNumber());
               stmt.setString(2, valueObject.getAuthorizedRepresentativeSignature());
               stmt.setDate(3, valueObject.getSignedDate());
               stmt.setString(4, valueObject.getAgencySchemaVersion());
               stmt.setString(5, valueObject.getFromVersionIdentifier());
               stmt.setString(6, valueObject.getSubmissionTypeCode());
               stmt.setDate(7, valueObject.getSubmittedDate());
               stmt.setString(8, valueObject.getApplicationTypeCode());
               stmt.setString(9, valueObject.getAgencyName());
               stmt.setDate(10, valueObject.getAgencyReceivedDate());
               stmt.setDate(11, valueObject.getStateReceivedDate());
               stmt.setString(12, valueObject.getStateID());
               stmt.setString(13, valueObject.getFederalID());
               stmt.setString(14, valueObject.getCFDANumber());
               stmt.setString(15, valueObject.getActivityTitle());
               stmt.setInt(16, valueObject.getAssurance());
               stmt.setString(17, valueObject.getStateReviewCode());
               stmt.setDate(18, valueObject.getStateReviewDate());
               stmt.setString(19, valueObject.getRevisionCode1());
               stmt.setString(20, valueObject.getRevisionCode2());
               stmt.setString(21, valueObject.getRevisionOtherExplanation());
               stmt.setString(22, valueObject.getApplicantID());
               stmt.setString(23, valueObject.getApplicantTypeCode());
               stmt.setString(24, valueObject.getApplicantTypeCodeOtherExplanation());
               stmt.setString(25, valueObject.getOrganizationName());
               stmt.setString(26, valueObject.getDUNSID());
               stmt.setString(27, valueObject.getDepartmentName());
               stmt.setString(28, valueObject.getDivisionName());
               stmt.setString(29, valueObject.getEmployerID());
               stmt.setString(30, valueObject.getStreet());
               stmt.setString(31, valueObject.getCity());
               stmt.setString(32, valueObject.getCounty());
               stmt.setString(33, valueObject.getStateCode());
               stmt.setString(34, valueObject.getZipCode());
               stmt.setString(35, valueObject.getCountry());
               stmt.setInt(36, valueObject.getDelinquentFederalDebtIndicator());
               stmt.setString(37, valueObject.getDelinquentFederalDebtExplanation());
               stmt.setString(38, valueObject.getOrganizationCongressionalDistrict());
               stmt.setString(39, valueObject.getProjectTitle());
               stmt.setString(40, valueObject.getLocation());
               stmt.setDate(41, valueObject.getProposedStartDate());
               stmt.setDate(42, valueObject.getProposedEndDate());
               stmt.setString(43, valueObject.getProjectCongressionalDistrict());
               stmt.setBigDecimal(44, valueObject.getFederalEstimatedAmount());
               stmt.setBigDecimal(45, valueObject.getApplicantEstimatedAmount());
               stmt.setBigDecimal(46, valueObject.getStateEstimatedAmount());
               stmt.setBigDecimal(47, valueObject.getLocalEstimatedAmount());
               stmt.setBigDecimal(48, valueObject.getOtherEstimatedAmount());
               stmt.setBigDecimal(49, valueObject.getProgramIncomeEstimatedAmount());
               stmt.setBigDecimal(50, valueObject.getTotalEstimatedAmount());
               stmt.setString(51, valueObject.getApplicantNamePrefix());
               stmt.setString(52, valueObject.getApplicantGivenName1());
               stmt.setString(53, valueObject.getApplicantGivenName2());
               stmt.setString(54, valueObject.getApplicantFamilyName());
               stmt.setString(55, valueObject.getApplicantNameSuffix());
               stmt.setString(56, valueObject.getApplicantTelephoneNumber());
               stmt.setString(57, valueObject.getApplicantFaxNumber());
               stmt.setString(58, valueObject.getApplicantEmail());
               stmt.setString(59, valueObject.getAORNamePrefix());
               stmt.setString(60, valueObject.getAORGivenName1());
               stmt.setString(61, valueObject.getAORGivenName2());
               stmt.setString(62, valueObject.getAORFamilyName());
               stmt.setString(63, valueObject.getAORNameSuffix());
               stmt.setString(64, valueObject.getAORTelephoneNumber());
               stmt.setString(65, valueObject.getAgencyTrackingNumber());
               stmt.setString(66, valueObject.getRepresentativeTitle());

               int rowcount = databaseUpdate(conn, stmt);
               if (rowcount != 1) {
                    //System.out.println("PrimaryKey Error when updating DB!");
                    throw new SQLException("PrimaryKey Error when updating DB!");
               }

          } finally {
              if (stmt != null)
                  stmt.close();
          }

    }


    /**
     * save-method. This method will save the current state of valueObject to database.
     * Save can not be used to create new instances in database, so upper layer must
     * make sure that the primary-key is correctly specified. Primary-key will indicate
     * which instance is going to be updated in database.
     *
     * @param conn         This method requires working database connection.
     * @param valueObject  This parameter contains the class instance to be saved.
     *                     Primary-key field must be set for this to work properly.
     */
    public static void save(Connection conn, Sf424Cover valueObject) throws SQLException {

          String sql = "UPDATE Sf424Cover SET Grants_govTrackingNumber = ?, AuthorizedRepresentativeSignature = ?, SignedDate = ?" +
          ", AgencySchemaVersion = ?, FromVersionIdentifier = ?, SubmissionTypeCode = ?" +
          ", SubmittedDate = ?, ApplicationTypeCode = ?, AgencyName = ?" +
          ", AgencyReceivedDate = ?, StateReceivedDate = ?, StateID = ?" +
          ", FederalID = ?, CFDANumber = ?, ActivityTitle = ?" +
          ", Assurance = ?, StateReviewCode = ?, StateReviewDate = ?, RevisionCode1 = ?, RevisionCode2 = ?" +
          ", RevisionOtherExplanation = ?, ApplicantID = ?, ApplicantTypeCode = ?" +
          ", ApplicantTypeCodeOtherExplanation = ?, OrganizationName = ?, DUNSID = ?" +
          ", DepartmentName = ?, DivisionName = ?, EmployerID = ?" +
          ", Street = ?, City = ?, County = ?" +
          ", StateCode = ?, ZipCode = ?, Country = ?, DelinquentFederalDebtIndicator = ?, DelinquentFederalDebtExplanation = ?" +
          ", OrganizationCongressionalDistrict = ?, ProjectTitle = ?, Location = ?" +
          ", ProposedStartDate = ?, ProposedEndDate = ?, ProjectCongressionalDistrict = ?" +
          ", FederalEstimatedAmount = ?, ApplicantEstimatedAmount = ?, StateEstimatedAmount = ?" +
          ", LocalEstimatedAmount = ?, OtherEstimatedAmount = ?, ProgramIncomeEstimatedAmount = ?" +
          ", TotalEstimatedAmount = ?, ApplicantNamePrefix = ?, ApplicantGivenName1 = ?, ApplicantGivenName2 = ?, ApplicantFamilyName = ?" +
          ", ApplicantNameSuffix = ?, ApplicantTelephoneNumber = ?, ApplicantFaxNumber = ?" +
          ", ApplicantEmail = ?, AORNamePrefix = ?, AORGivenName1 = ?" +
          ", AORGivenName2 = ?, AORFamilyName = ?, AORNameSuffix = ?" +
          ", AORTelephoneNumber = ?, AgencyTrackingNumber = ?, RepresentativeTitle = ? WHERE Grants_govTrackingNumber = ?";

          PreparedStatement stmt = null;

          try {
              stmt = conn.prepareStatement(sql);

              stmt.setString(1, valueObject.getGrants_govTrackingNumber());
              stmt.setString(2, valueObject.getAuthorizedRepresentativeSignature());
              stmt.setDate(3, valueObject.getSignedDate());
              stmt.setString(4, valueObject.getAgencySchemaVersion());
              stmt.setString(5, valueObject.getFromVersionIdentifier());
              stmt.setString(6, valueObject.getSubmissionTypeCode());
              stmt.setDate(7, valueObject.getSubmittedDate());
              stmt.setString(8, valueObject.getApplicationTypeCode());
              stmt.setString(9, valueObject.getAgencyName());
              stmt.setDate(10, valueObject.getAgencyReceivedDate());
              stmt.setDate(11, valueObject.getStateReceivedDate());
              stmt.setString(12, valueObject.getStateID());
              stmt.setString(13, valueObject.getFederalID());
              stmt.setString(14, valueObject.getCFDANumber());
              stmt.setString(15, valueObject.getActivityTitle());
              stmt.setInt(16, valueObject.getAssurance());
              stmt.setString(17, valueObject.getStateReviewCode());
              stmt.setDate(18, valueObject.getStateReviewDate());
              stmt.setString(19, valueObject.getRevisionCode1());
              stmt.setString(20, valueObject.getRevisionCode2());
              stmt.setString(21, valueObject.getRevisionOtherExplanation());
              stmt.setString(22, valueObject.getApplicantID());
              stmt.setString(23, valueObject.getApplicantTypeCode());
              stmt.setString(24, valueObject.getApplicantTypeCodeOtherExplanation());
              stmt.setString(25, valueObject.getOrganizationName());
              stmt.setString(26, valueObject.getDUNSID());
              stmt.setString(27, valueObject.getDepartmentName());
              stmt.setString(28, valueObject.getDivisionName());
              stmt.setString(29, valueObject.getEmployerID());
              stmt.setString(30, valueObject.getStreet());
              stmt.setString(31, valueObject.getCity());
              stmt.setString(32, valueObject.getCounty());
              stmt.setString(33, valueObject.getStateCode());
              stmt.setString(34, valueObject.getZipCode());
              stmt.setString(35, valueObject.getCountry());
              stmt.setInt(36, valueObject.getDelinquentFederalDebtIndicator());
              stmt.setString(37, valueObject.getDelinquentFederalDebtExplanation());
              stmt.setString(38, valueObject.getOrganizationCongressionalDistrict());
              stmt.setString(39, valueObject.getProjectTitle());
              stmt.setString(40, valueObject.getLocation());
              stmt.setDate(41, valueObject.getProposedStartDate());
              stmt.setDate(42, valueObject.getProposedEndDate());
              stmt.setString(43, valueObject.getProjectCongressionalDistrict());
              stmt.setBigDecimal(44, valueObject.getFederalEstimatedAmount());
              stmt.setBigDecimal(45, valueObject.getApplicantEstimatedAmount());
              stmt.setBigDecimal(46, valueObject.getStateEstimatedAmount());
              stmt.setBigDecimal(47, valueObject.getLocalEstimatedAmount());
              stmt.setBigDecimal(48, valueObject.getOtherEstimatedAmount());
              stmt.setBigDecimal(49, valueObject.getProgramIncomeEstimatedAmount());
              stmt.setBigDecimal(50, valueObject.getTotalEstimatedAmount());
              stmt.setString(51, valueObject.getApplicantNamePrefix());
              stmt.setString(52, valueObject.getApplicantGivenName1());
              stmt.setString(53, valueObject.getApplicantGivenName2());
              stmt.setString(54, valueObject.getApplicantFamilyName());
              stmt.setString(55, valueObject.getApplicantNameSuffix());
              stmt.setString(56, valueObject.getApplicantTelephoneNumber());
              stmt.setString(57, valueObject.getApplicantFaxNumber());
              stmt.setString(58, valueObject.getApplicantEmail());
              stmt.setString(59, valueObject.getAORNamePrefix());
              stmt.setString(60, valueObject.getAORGivenName1());
              stmt.setString(61, valueObject.getAORGivenName2());
              stmt.setString(62, valueObject.getAORFamilyName());
              stmt.setString(63, valueObject.getAORNameSuffix());
              stmt.setString(64, valueObject.getAORTelephoneNumber());
              stmt.setString(65, valueObject.getAgencyTrackingNumber());
              stmt.setString(66, valueObject.getRepresentativeTitle());
              stmt.setString(67, valueObject.getGrants_govTrackingNumber());





              int rowcount = databaseUpdate(conn, stmt);
              if (rowcount != 1) {
                   //System.out.println("PrimaryKey Error when updating DB!");
                   throw new SQLException("PrimaryKey Error when updating DB!");
              }
          } finally {
              if (stmt != null)
                  stmt.close();
          }
    }


    /**
     * delete-method. This method will remove the information from database as identified by
     * by primary-key in supplied valueObject. Once valueObject has been deleted it can not
     * be restored by calling save. Restoring can only be done using create method but if
     * database is using automatic surrogate-keys, the resulting object will have different
     * primary-key than what it was in the deleted object.
     *
     * @param conn         This method requires working database connection.
     * @param valueObject  This parameter contains the class instance to be deleted.
     *                     Primary-key field must be set for this to work properly.
     */
    public static void delete(Connection conn, Sf424Cover valueObject) throws SQLException {

          if (valueObject.getGrants_govTrackingNumber() == null) {
               //System.out.println("Can not delete without Primary-Key!");
               throw new SQLException("Can not delete without Primary-Key!");
          }
          String sql = "DELETE FROM Sf424Cover WHERE Grants_govTrackingNumber = ?";
          PreparedStatement stmt = null;

          try {
              stmt = conn.prepareStatement(sql);

               stmt.setString(1, valueObject.getGrants_govTrackingNumber());

              int rowcount = databaseUpdate(conn, stmt);
              if (rowcount != 1) {
                   //System.out.println("PrimaryKey Error when updating DB!");
                   throw new SQLException("PrimaryKey Error when updating DB!");
              }
          } finally {
              if (stmt != null)
                  stmt.close();
          }
    }


    /**
     * deleteAll-method. This method will remove all information from the table that matches
     * this Dao and ValueObject couple. This should be the most efficient way to clear table.
     * Once deleteAll has been called, no valueObject that has been created before can be
     * restored by calling save. Restoring can only be done using create method but if database
     * is using automatic surrogate-keys, the resulting object will have different primary-key
     * than what it was in the deleted object. (Note, the implementation of this method should
     * be different with different DB backends.)
     *
     * @param conn         This method requires working database connection.
     */
    public static void deleteAll(Connection conn) throws SQLException {

          String sql = "DELETE FROM Sf424Cover";
          PreparedStatement stmt = null;

          try {
              stmt = conn.prepareStatement(sql);
              int rowcount = databaseUpdate(conn, stmt);
          } finally {
              if (stmt != null)
                  stmt.close();
          }
    }


    /**
     * coutAll-method. This method will return the number of all rows from table that matches
     * this Dao. The implementation will simply execute "select count(primarykey) from table".
     * If table is empty, the return value is 0. This method should be used before calling
     * loadAll, to make sure table has not too many rows.
     *
     * @param conn         This method requires working database connection.
     */
    public static int countAll(Connection conn) throws SQLException {

          String sql = "SELECT count(Grants_govTrackingNumber) FROM Sf424Cover";
          PreparedStatement stmt = null;
          ResultSet result = null;
          int allRows = 0;

          try {
              stmt = conn.prepareStatement(sql);
              result = stmt.executeQuery();

              if (result.next())
                  allRows = result.getInt(1);
          } finally {
              if (result != null)
                  result.close();
              if (stmt != null)
                  stmt.close();
          }
          return allRows;
    }


    /**
     * searchMatching-Method. This method provides searching capability to
     * get matching valueObjects from database. It works by searching all
     * objects that match permanent instance variables of given object.
     * Upper layer should use this by setting some parameters in valueObject
     * and then  call searchMatching. The result will be 0-N objects in vector,
     * all matching those criteria you specified. Those instance-variables that
     * have NULL values are excluded in search-criteria.
     *
     * @param conn         This method requires working database connection.
     * @param valueObject  This parameter contains the class instance where search will be based.
     *                     Primary-key field should not be set.
     */
    public static List searchMatching(Connection conn, Sf424Cover valueObject) throws SQLException {

          List searchResults;

          boolean first = true;
          StringBuffer sql = new StringBuffer("SELECT * FROM Sf424Cover WHERE 1=1 ");
          if (valueObject.getGrants_govTrackingNumber() != null) {
              if (first) { first = false; }
              sql.append("AND Grants_govTrackingNumber LIKE '").append(valueObject.getGrants_govTrackingNumber()).append("%' ");
          }

          if (valueObject.getAuthorizedRepresentativeSignature() != null) {
              if (first) { first = false; }
              sql.append("AND AuthorizedRepresentativeSignature LIKE '").append(valueObject.getAuthorizedRepresentativeSignature()).append("%' ");
          }

          if (valueObject.getSignedDate() != null) {
              if (first) { first = false; }
              sql.append("AND SignedDate = '").append(valueObject.getSignedDate()).append("' ");
          }

          if (valueObject.getAgencySchemaVersion() != null) {
              if (first) { first = false; }
              sql.append("AND AgencySchemaVersion LIKE '").append(valueObject.getAgencySchemaVersion()).append("%' ");
          }

          if (valueObject.getFromVersionIdentifier() != null) {
              if (first) { first = false; }
              sql.append("AND FromVersionIdentifier LIKE '").append(valueObject.getFromVersionIdentifier()).append("%' ");
          }

          if (valueObject.getSubmissionTypeCode() != null) {
              if (first) { first = false; }
              sql.append("AND SubmissionTypeCode LIKE '").append(valueObject.getSubmissionTypeCode()).append("%' ");
          }

          if (valueObject.getSubmittedDate() != null) {
              if (first) { first = false; }
              sql.append("AND SubmittedDate = '").append(valueObject.getSubmittedDate()).append("' ");
          }

          if (valueObject.getApplicationTypeCode() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicationTypeCode LIKE '").append(valueObject.getApplicationTypeCode()).append("%' ");
          }

          if (valueObject.getAgencyName() != null) {
              if (first) { first = false; }
              sql.append("AND AgencyName LIKE '").append(valueObject.getAgencyName()).append("%' ");
          }

          if (valueObject.getAgencyReceivedDate() != null) {
              if (first) { first = false; }
              sql.append("AND AgencyReceivedDate = '").append(valueObject.getAgencyReceivedDate()).append("' ");
          }

          if (valueObject.getStateReceivedDate() != null) {
              if (first) { first = false; }
              sql.append("AND StateReceivedDate = '").append(valueObject.getStateReceivedDate()).append("' ");
          }

          if (valueObject.getStateID() != null) {
              if (first) { first = false; }
              sql.append("AND StateID LIKE '").append(valueObject.getStateID()).append("%' ");
          }

          if (valueObject.getFederalID() != null) {
              if (first) { first = false; }
              sql.append("AND FederalID LIKE '").append(valueObject.getFederalID()).append("%' ");
          }

          if (valueObject.getCFDANumber() != null) {
              if (first) { first = false; }
              sql.append("AND CFDANumber LIKE '").append(valueObject.getCFDANumber()).append("%' ");
          }

          if (valueObject.getActivityTitle() != null) {
              if (first) { first = false; }
              sql.append("AND ActivityTitle LIKE '").append(valueObject.getActivityTitle()).append("%' ");
          }

          if (valueObject.getAssurance() != 0) {
              if (first) { first = false; }
              sql.append("AND Assurance = ").append(valueObject.getAssurance()).append(" ");
          }

          if (valueObject.getStateReviewCode() != null) {
              if (first) { first = false; }
              sql.append("AND StateReviewCode LIKE '").append(valueObject.getStateReviewCode()).append("%' ");
          }

          if (valueObject.getStateReviewDate() != null) {
              if (first) { first = false; }
              sql.append("AND StateReviewDate = '").append(valueObject.getStateReviewDate()).append("' ");
          }


          if (valueObject.getRevisionCode1() != null) {
              if (first) { first = false; }
              sql.append("AND RevisionCode1 LIKE '").append(valueObject.getRevisionCode1()).append("%' ");
          }

          if (valueObject.getRevisionCode2() != null) {
              if (first) { first = false; }
              sql.append("AND RevisionCode2 LIKE '").append(valueObject.getRevisionCode2()).append("%' ");
          }

          if (valueObject.getRevisionOtherExplanation() != null) {
              if (first) { first = false; }
              sql.append("AND RevisionOtherExplanation LIKE '").append(valueObject.getRevisionOtherExplanation()).append("%' ");
          }

          if (valueObject.getApplicantID() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicantID LIKE '").append(valueObject.getApplicantID()).append("%' ");
          }

          if (valueObject.getApplicantTypeCode() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicantTypeCode LIKE '").append(valueObject.getApplicantTypeCode()).append("%' ");
          }

          if (valueObject.getApplicantTypeCodeOtherExplanation() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicantTypeCodeOtherExplanation LIKE '").append(valueObject.getApplicantTypeCodeOtherExplanation()).append("%' ");
          }

          if (valueObject.getOrganizationName() != null) {
              if (first) { first = false; }
              sql.append("AND OrganizationName LIKE '").append(valueObject.getOrganizationName()).append("%' ");
          }

          if (valueObject.getDUNSID() != null) {
              if (first) { first = false; }
              sql.append("AND DUNSID LIKE '").append(valueObject.getDUNSID()).append("%' ");
          }

          if (valueObject.getDepartmentName() != null) {
              if (first) { first = false; }
              sql.append("AND DepartmentName LIKE '").append(valueObject.getDepartmentName()).append("%' ");
          }

          if (valueObject.getDivisionName() != null) {
              if (first) { first = false; }
              sql.append("AND DivisionName LIKE '").append(valueObject.getDivisionName()).append("%' ");
          }

          if (valueObject.getEmployerID() != null) {
              if (first) { first = false; }
              sql.append("AND EmployerID LIKE '").append(valueObject.getEmployerID()).append("%' ");
          }

          if (valueObject.getStreet() != null) {
              if (first) { first = false; }
              sql.append("AND Street LIKE '").append(valueObject.getStreet()).append("%' ");
          }

          if (valueObject.getCity() != null) {
              if (first) { first = false; }
              sql.append("AND City LIKE '").append(valueObject.getCity()).append("%' ");
          }

          if (valueObject.getCounty() != null) {
              if (first) { first = false; }
              sql.append("AND County LIKE '").append(valueObject.getCounty()).append("%' ");
          }

          if (valueObject.getStateCode() != null) {
              if (first) { first = false; }
              sql.append("AND StateCode LIKE '").append(valueObject.getStateCode()).append("%' ");
          }

          if (valueObject.getZipCode() != null) {
              if (first) { first = false; }
              sql.append("AND ZipCode LIKE '").append(valueObject.getZipCode()).append("%' ");
          }

          if (valueObject.getCountry() != null) {
              if (first) { first = false; }
              sql.append("AND Country LIKE '").append(valueObject.getCountry()).append("%' ");
          }

          if (valueObject.getDelinquentFederalDebtIndicator() != 0) {
              if (first) { first = false; }
              sql.append("AND DelinquentFederalDebtIndicator = ").append(valueObject.getDelinquentFederalDebtIndicator()).append(" ");
          }

          if (valueObject.getDelinquentFederalDebtExplanation() != null) {
              if (first) { first = false; }
              sql.append("AND DelinquentFederalDebtExplanation LIKE '").append(valueObject.getDelinquentFederalDebtExplanation()).append("%' ");
          }

          if (valueObject.getOrganizationCongressionalDistrict() != null) {
              if (first) { first = false; }
              sql.append("AND OrganizationCongressionalDistrict LIKE '").append(valueObject.getOrganizationCongressionalDistrict()).append("%' ");
          }

          if (valueObject.getProjectTitle() != null) {
              if (first) { first = false; }
              sql.append("AND ProjectTitle LIKE '").append(valueObject.getProjectTitle()).append("%' ");
          }

          if (valueObject.getLocation() != null) {
              if (first) { first = false; }
              sql.append("AND Location LIKE '").append(valueObject.getLocation()).append("%' ");
          }

          if (valueObject.getProposedStartDate() != null) {
              if (first) { first = false; }
              sql.append("AND ProposedStartDate = '").append(valueObject.getProposedStartDate()).append("' ");
          }

          if (valueObject.getProposedEndDate() != null) {
              if (first) { first = false; }
              sql.append("AND ProposedEndDate = '").append(valueObject.getProposedEndDate()).append("' ");
          }

          if (valueObject.getProjectCongressionalDistrict() != null) {
              if (first) { first = false; }
              sql.append("AND ProjectCongressionalDistrict LIKE '").append(valueObject.getProjectCongressionalDistrict()).append("%' ");
          }

          if (valueObject.getFederalEstimatedAmount() != null) {
              if (first) { first = false; }
              sql.append("AND FederalEstimatedAmount = '").append(valueObject.getFederalEstimatedAmount()).append("' ");
          }

          if (valueObject.getApplicantEstimatedAmount() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicantEstimatedAmount = '").append(valueObject.getApplicantEstimatedAmount()).append("' ");
          }

          if (valueObject.getStateEstimatedAmount() != null) {
              if (first) { first = false; }
              sql.append("AND StateEstimatedAmount = '").append(valueObject.getStateEstimatedAmount()).append("' ");
          }

          if (valueObject.getLocalEstimatedAmount() != null) {
              if (first) { first = false; }
              sql.append("AND LocalEstimatedAmount = '").append(valueObject.getLocalEstimatedAmount()).append("' ");
          }

          if (valueObject.getOtherEstimatedAmount() != null) {
              if (first) { first = false; }
              sql.append("AND OtherEstimatedAmount = '").append(valueObject.getOtherEstimatedAmount()).append("' ");
          }

          if (valueObject.getProgramIncomeEstimatedAmount() != null) {
              if (first) { first = false; }
              sql.append("AND ProgramIncomeEstimatedAmount = '").append(valueObject.getProgramIncomeEstimatedAmount()).append("' ");
          }

          if (valueObject.getTotalEstimatedAmount() != null) {
              if (first) { first = false; }
              sql.append("AND TotalEstimatedAmount = '").append(valueObject.getTotalEstimatedAmount()).append("' ");
          }

          if (valueObject.getApplicantNamePrefix() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicantNamePrefix LIKE '").append(valueObject.getApplicantNamePrefix()).append("%' ");
          }

          if (valueObject.getApplicantGivenName1() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicantGivenName1 LIKE '").append(valueObject.getApplicantGivenName1()).append("%' ");
          }

          if (valueObject.getApplicantGivenName2() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicantGivenName2 LIKE '").append(valueObject.getApplicantGivenName2()).append("%' ");
          }

          if (valueObject.getApplicantFamilyName() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicantFamilyName LIKE '").append(valueObject.getApplicantFamilyName()).append("%' ");
          }

          if (valueObject.getApplicantNameSuffix() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicantNameSuffix LIKE '").append(valueObject.getApplicantNameSuffix()).append("%' ");
          }

          if (valueObject.getApplicantTelephoneNumber() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicantTelephoneNumber LIKE '").append(valueObject.getApplicantTelephoneNumber()).append("%' ");
          }

          if (valueObject.getApplicantFaxNumber() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicantFaxNumber LIKE '").append(valueObject.getApplicantFaxNumber()).append("%' ");
          }

          if (valueObject.getApplicantEmail() != null) {
              if (first) { first = false; }
              sql.append("AND ApplicantEmail LIKE '").append(valueObject.getApplicantEmail()).append("%' ");
          }

          if (valueObject.getAORNamePrefix() != null) {
              if (first) { first = false; }
              sql.append("AND AORNamePrefix LIKE '").append(valueObject.getAORNamePrefix()).append("%' ");
          }

          if (valueObject.getAORGivenName1() != null) {
              if (first) { first = false; }
              sql.append("AND AORGivenName1 LIKE '").append(valueObject.getAORGivenName1()).append("%' ");
          }

          if (valueObject.getAORGivenName2() != null) {
              if (first) { first = false; }
              sql.append("AND AORGivenName2 LIKE '").append(valueObject.getAORGivenName2()).append("%' ");
          }

          if (valueObject.getAORFamilyName() != null) {
              if (first) { first = false; }
              sql.append("AND AORFamilyName LIKE '").append(valueObject.getAORFamilyName()).append("%' ");
          }

          if (valueObject.getAORNameSuffix() != null) {
              if (first) { first = false; }
              sql.append("AND AORNameSuffix LIKE '").append(valueObject.getAORNameSuffix()).append("%' ");
          }

          if (valueObject.getAORTelephoneNumber() != null) {
              if (first) { first = false; }
              sql.append("AND AORTelephoneNumber LIKE '").append(valueObject.getAORTelephoneNumber()).append("%' ");
          }

          if (valueObject.getAgencyTrackingNumber() != null) {
              if (first) { first = false; }
              sql.append("AND AgencyTrackingNumber LIKE '").append(valueObject.getAgencyTrackingNumber()).append("%' ");
          }

          if (valueObject.getRepresentativeTitle() != null) {
              if (first) { first = false; }
              sql.append("AND RepresentativeTitle LIKE '").append(valueObject.getRepresentativeTitle()).append("%' ");
          }


          sql.append("ORDER BY Grants_govTrackingNumber ");

          // Prevent accidential full table results.
          // Use loadAll if all rows must be returned.
          if (first)
               searchResults = new Vector();
          else
               searchResults = listQuery(conn, conn.prepareStatement(sql.toString()));

          return searchResults;
    }


    /**
     * getDaogenVersion will return information about
     * generator which created these sources.
     */
    public String getDaogenVersion() {
        return "DaoGen version 0.99.0";
    }


    /**
     * databaseUpdate-method. This method is a helper method for internal use. It will execute
     * all database handling that will change the information in tables. SELECT queries will
     * not be executed here however. The return value indicates how many rows were affected.
     * This method will also make sure that if cache is used, it will reset when data changes.
     *
     * @param conn         This method requires working database connection.
     * @param stmt         This parameter contains the SQL statement to be excuted.
     */
    protected static int databaseUpdate(Connection conn, PreparedStatement stmt) throws SQLException {

          int result = stmt.executeUpdate();
          return result;
    }



    /**
     * databaseQuery-method. This method is a helper method for internal use. It will execute
     * all database queries that will return only one row. The resultset will be converted
     * to valueObject. If no rows were found, an exception will be thrown.
     *
     * @param conn         This method requires working database connection.
     * @param stmt         This parameter contains the SQL statement to be excuted.
     * @param valueObject  Class-instance where resulting data will be stored.
     */
    protected static void singleQuery(Connection conn, PreparedStatement stmt, Sf424Cover valueObject) throws SQLException {

          ResultSet result = null;

          try {
              result = stmt.executeQuery();

			  if (result.next()) {
                   valueObject.setGrants_govTrackingNumber(result.getString("Grants_govTrackingNumber"));
                   valueObject.setAuthorizedRepresentativeSignature(result.getString("AuthorizedRepresentativeSignature"));
                   valueObject.setSignedDate(result.getDate("SignedDate"));
                   valueObject.setAgencySchemaVersion(result.getString("AgencySchemaVersion"));
                   valueObject.setFromVersionIdentifier(result.getString("FromVersionIdentifier"));
                   valueObject.setSubmissionTypeCode(result.getString("SubmissionTypeCode"));
                   valueObject.setSubmittedDate(result.getDate("SubmittedDate"));
                   valueObject.setApplicationTypeCode(result.getString("ApplicationTypeCode"));
                   valueObject.setAgencyName(result.getString("AgencyName"));
                   valueObject.setAgencyReceivedDate(result.getDate("AgencyReceivedDate"));
                   valueObject.setStateReceivedDate(result.getDate("StateReceivedDate"));
                   valueObject.setStateID(result.getString("StateID"));
                   valueObject.setFederalID(result.getString("FederalID"));
                   valueObject.setCFDANumber(result.getString("CFDANumber"));
                   valueObject.setActivityTitle(result.getString("ActivityTitle"));
                   valueObject.setAssurance(result.getInt("Assurance"));
                   valueObject.setStateReviewCode(result.getString("StateReviewCode"));
                   valueObject.setStateReviewDate(result.getDate("StateReviewDate"));
                   valueObject.setRevisionCode1(result.getString("RevisionCode1"));
                   valueObject.setRevisionCode2(result.getString("RevisionCode2"));
                   valueObject.setRevisionOtherExplanation(result.getString("RevisionOtherExplanation"));
                   valueObject.setApplicantID(result.getString("ApplicantID"));
                   valueObject.setApplicantTypeCode(result.getString("ApplicantTypeCode"));
                   valueObject.setApplicantTypeCodeOtherExplanation(result.getString("ApplicantTypeCodeOtherExplanation"));
                   valueObject.setOrganizationName(result.getString("OrganizationName"));
                   valueObject.setDUNSID(result.getString("DUNSID"));
                   valueObject.setDepartmentName(result.getString("DepartmentName"));
                   valueObject.setDivisionName(result.getString("DivisionName"));
                   valueObject.setEmployerID(result.getString("EmployerID"));
                   valueObject.setStreet(result.getString("Street"));
                   valueObject.setCity(result.getString("City"));
                   valueObject.setCounty(result.getString("County"));
                   valueObject.setStateCode(result.getString("StateCode"));
                   valueObject.setZipCode(result.getString("ZipCode"));
                   valueObject.setCountry(result.getString("Country"));
                   valueObject.setDelinquentFederalDebtIndicator(result.getInt("DelinquentFederalDebtIndicator"));
                   valueObject.setDelinquentFederalDebtExplanation(result.getString("DelinquentFederalDebtExplanation"));
                   valueObject.setOrganizationCongressionalDistrict(result.getString("OrganizationCongressionalDistrict"));
                   valueObject.setProjectTitle(result.getString("ProjectTitle"));
                   valueObject.setLocation(result.getString("Location"));
                   valueObject.setProposedStartDate(result.getDate("ProposedStartDate"));
                   valueObject.setProposedEndDate(result.getDate("ProposedEndDate"));
                   valueObject.setProjectCongressionalDistrict(result.getString("ProjectCongressionalDistrict"));
                   //valueObject.setFederalEstimatedAmount(result.getBigDecimal("FederalEstimatedAmount"));
                   //valueObject.setApplicantEstimatedAmount(result.getBigDecimal("ApplicantEstimatedAmount"));
                   //valueObject.setStateEstimatedAmount(result.getBigDecimal("StateEstimatedAmount"));
                   //valueObject.setLocalEstimatedAmount(result.getBigDecimal("LocalEstimatedAmount"));
                   //valueObject.setOtherEstimatedAmount(result.getBigDecimal("OtherEstimatedAmount"));
                   //valueObject.setProgramIncomeEstimatedAmount(result.getBigDecimal("ProgramIncomeEstimatedAmount"));
                   //valueObject.setTotalEstimatedAmount(result.getBigDecimal("TotalEstimatedAmount"));
                   valueObject.setApplicantNamePrefix(result.getString("ApplicantNamePrefix"));
                   valueObject.setApplicantGivenName1(result.getString("ApplicantGivenName1"));
                   valueObject.setApplicantGivenName2(result.getString("ApplicantGivenName2"));
                   valueObject.setApplicantFamilyName(result.getString("ApplicantFamilyName"));
                   valueObject.setApplicantNameSuffix(result.getString("ApplicantNameSuffix"));
                   valueObject.setApplicantTelephoneNumber(result.getString("ApplicantTelephoneNumber"));
                   valueObject.setApplicantFaxNumber(result.getString("ApplicantFaxNumber"));
                   valueObject.setApplicantEmail(result.getString("ApplicantEmail"));
                   valueObject.setAORNamePrefix(result.getString("AORNamePrefix"));
                   valueObject.setAORGivenName1(result.getString("AORGivenName1"));
                   valueObject.setAORGivenName2(result.getString("AORGivenName2"));
                   valueObject.setAORFamilyName(result.getString("AORFamilyName"));
                   valueObject.setAORNameSuffix(result.getString("AORNameSuffix"));
                   valueObject.setAORTelephoneNumber(result.getString("AORTelephoneNumber"));
                   valueObject.setAgencyTrackingNumber(result.getString("AgencyTrackingNumber"));
                   valueObject.setRepresentativeTitle(result.getString("RepresentativeTitle"));

				   System.out.println( "Done Copying result values to cover value object" );
				   
              } else {
                    //System.out.println("Sf424Cover Object Not Found!");
                    throw new SQLException("Sf424Cover Object Not Found!");
              }
          } finally {
              if (result != null)
                  result.close();
              if (stmt != null)
                  stmt.close();
          }
    }


    /**
     * databaseQuery-method. This method is a helper method for internal use. It will execute
     * all database queries that will return multiple rows. The resultset will be converted
     * to the List of valueObjects. If no rows were found, an empty List will be returned.
     *
     * @param conn         This method requires working database connection.
     * @param stmt         This parameter contains the SQL statement to be excuted.
     */
    protected static List listQuery(Connection conn, PreparedStatement stmt) throws SQLException {

          Vector searchResults = new Vector();
          ResultSet result = null;

          try {
              result = stmt.executeQuery();

              while (result.next()) {
                   Sf424Cover temp = new Sf424Cover();
                   temp.setGrants_govTrackingNumber(result.getString("Grants_govTrackingNumber"));
                   temp.setAuthorizedRepresentativeSignature(result.getString("AuthorizedRepresentativeSignature"));
                   temp.setSignedDate(result.getDate("SignedDate"));
                   temp.setAgencySchemaVersion(result.getString("AgencySchemaVersion"));
                   temp.setFromVersionIdentifier(result.getString("FromVersionIdentifier"));
                   temp.setSubmissionTypeCode(result.getString("SubmissionTypeCode"));
                   temp.setSubmittedDate(result.getDate("SubmittedDate"));
                   temp.setApplicationTypeCode(result.getString("ApplicationTypeCode"));
                   temp.setAgencyName(result.getString("AgencyName"));
                   temp.setAgencyReceivedDate(result.getDate("AgencyReceivedDate"));
                   temp.setStateReceivedDate(result.getDate("StateReceivedDate"));
                   temp.setStateID(result.getString("StateID"));
                   temp.setFederalID(result.getString("FederalID"));
                   temp.setCFDANumber(result.getString("CFDANumber"));
                   temp.setActivityTitle(result.getString("ActivityTitle"));
                   temp.setAssurance(result.getInt("Assurance"));
                   temp.setStateReviewCode(result.getString("StateReviewCode"));
                   temp.setStateReviewDate(result.getDate("StateReviewDate"));
                   temp.setRevisionCode1(result.getString("RevisionCode1"));
                   temp.setRevisionCode2(result.getString("RevisionCode2"));
                   temp.setRevisionOtherExplanation(result.getString("RevisionOtherExplanation"));
                   temp.setApplicantID(result.getString("ApplicantID"));
                   temp.setApplicantTypeCode(result.getString("ApplicantTypeCode"));
                   temp.setApplicantTypeCodeOtherExplanation(result.getString("ApplicantTypeCodeOtherExplanation"));
                   temp.setOrganizationName(result.getString("OrganizationName"));
                   temp.setDUNSID(result.getString("DUNSID"));
                   temp.setDepartmentName(result.getString("DepartmentName"));
                   temp.setDivisionName(result.getString("DivisionName"));
                   temp.setEmployerID(result.getString("EmployerID"));
                   temp.setStreet(result.getString("Street"));
                   temp.setCity(result.getString("City"));
                   temp.setCounty(result.getString("County"));
                   temp.setStateCode(result.getString("StateCode"));
                   temp.setZipCode(result.getString("ZipCode"));
                   temp.setCountry(result.getString("Country"));
                   temp.setGrants_govTrackingNumber(result.getString("Grants_govTrackingNumber"));
                   temp.setDelinquentFederalDebtIndicator(result.getInt("DelinquentFederalDebtIndicator"));
                   temp.setDelinquentFederalDebtExplanation(result.getString("DelinquentFederalDebtExplanation"));
                   temp.setOrganizationCongressionalDistrict(result.getString("OrganizationCongressionalDistrict"));
                   temp.setProjectTitle(result.getString("ProjectTitle"));
                   temp.setLocation(result.getString("Location"));
                   temp.setProposedStartDate(result.getDate("ProposedStartDate"));
                   temp.setProposedEndDate(result.getDate("ProposedEndDate"));
                   temp.setProjectCongressionalDistrict(result.getString("ProjectCongressionalDistrict"));
//                   temp.setFederalEstimatedAmount(result.getBigDecimal("FederalEstimatedAmount"));
//                   temp.setApplicantEstimatedAmount(result.getBigDecimal("ApplicantEstimatedAmount"));
//                   temp.setStateEstimatedAmount(result.getBigDecimal("StateEstimatedAmount"));
//                   temp.setLocalEstimatedAmount(result.getBigDecimal("LocalEstimatedAmount"));
//                   temp.setOtherEstimatedAmount(result.getBigDecimal("OtherEstimatedAmount"));
//                   temp.setProgramIncomeEstimatedAmount(result.getBigDecimal("ProgramIncomeEstimatedAmount"));
                   temp.setTotalEstimatedAmount(result.getBigDecimal("TotalEstimatedAmount"));
                   temp.setApplicantNamePrefix(result.getString("ApplicantNamePrefix"));
                   temp.setApplicantGivenName1(result.getString("ApplicantGivenName1"));
                   temp.setApplicantGivenName2(result.getString("ApplicantGivenName2"));
                   temp.setApplicantFamilyName(result.getString("ApplicantFamilyName"));
                   temp.setApplicantNameSuffix(result.getString("ApplicantNameSuffix"));
                   temp.setApplicantTelephoneNumber(result.getString("ApplicantTelephoneNumber"));
                   temp.setApplicantFaxNumber(result.getString("ApplicantFaxNumber"));
                   temp.setApplicantEmail(result.getString("ApplicantEmail"));
                   temp.setAORNamePrefix(result.getString("AORNamePrefix"));
                   temp.setAORGivenName1(result.getString("AORGivenName1"));
                   temp.setAORGivenName2(result.getString("AORGivenName2"));
                   temp.setAORFamilyName(result.getString("AORFamilyName"));
                   temp.setAORNameSuffix(result.getString("AORNameSuffix"));
                   temp.setAORTelephoneNumber(result.getString("AORTelephoneNumber"));
                   temp.setAgencyTrackingNumber(result.getString("AgencyTrackingNumber"));
                   temp.setRepresentativeTitle(result.getString("RepresentativeTitle"));

                   searchResults.add(temp);
              }

          } finally {
              if (result != null)
                  result.close();
              if (stmt != null)
                  stmt.close();
          }

          return (List)searchResults;
    }



}

