/*
 *  ViewApplicationDetailsServlet.java
 *
 *  @author :: Dan Dumitru ::
 *  Created on 2003-07-14
 *	
 *	This servlet performs the following high-level tasks:
 *  - load the Header, SF424 Cover, and Footer data from the database;
 *  - place the Header, SF424 Cover, and Footer data into the request;
 *  - forward to the Details.jsp page
 * 
 */
 
 package gov.grants.xmlToDB.servlet;

// Sun
import java.io.*;
import java.util.*;
import java.util.*;
import java.net.*;
import java.sql.*;
import java.text.*;

import javax.servlet.http.*;
import javax.servlet.*;

// Reference Implementation
import gov.grants.xmlToDB.utility.DaoMediator;
import gov.grants.xmlToDB.valueobject.*;


public class ViewApplicationDetailsServlet extends HttpServlet
{

	private RequestDispatcher rd;
	private Sf424header header;
	private Sf424Cover cover;
	private Sf424footer footer;
	
	public void doGet( HttpServletRequest request, HttpServletResponse response ) throws IOException,ServletException {
		doPost( request, response );
	}
	
	public void doPost(HttpServletRequest request, HttpServletResponse response ) throws IOException,ServletException	{
		String filename = "";
		try {
			
			// Load the Header, SF424 Cover, and Footer data from the database
			String grants_govTrackingNumber = request.getParameter( "grants_govTrackingNumber" );
			System.out.println( "grants_govTrackingNumber= " + grants_govTrackingNumber );

			System.out.println( "Loading GrantSubmissionHeader from DB" );
			header = DaoMediator.loadHeader( grants_govTrackingNumber );
			
			System.out.println( "Loading GrantApplication from DB" );
			cover = DaoMediator.loadCover( grants_govTrackingNumber );
			
			System.out.println( "Loading GrantSubmissionFooter from DB" );
			footer = DaoMediator.loadFooter(  grants_govTrackingNumber );
			
		} catch( Exception e ) { 
			
			System.out.println( "ERROR encountered loading header, sf424 cover, or footer: " + e.getMessage() );
			
			request.setAttribute( "ErrorMsg", e.getMessage() );
			
			System.out.println( "Forwarding to /xmlToDB/jsp/include/xmlToDBErrorPage.jsp" );
			rd = request.getRequestDispatcher("/xmlToDB/jsp/include/xmlToDBErrorPage.jsp");
			rd.forward(request, response);
			return;
			
		}

		request.setAttribute( "Sf424header", header );
		request.setAttribute( "Sf424cover", cover );
		request.setAttribute( "Sf424footer", footer );
		
		System.out.println( "Forwarding to /xmlToDB/jsp/Details.jsp" );
		rd = request.getRequestDispatcher("/xmlToDB/jsp/Details.jsp");
		rd.forward(request, response);

	}
}// ViewApplicationDetailsServlet

